You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by sa...@apache.org on 2010/07/20 14:47:34 UTC

svn commit: r965830 - /click/trunk/click/framework/src/org/apache/click/ClickServlet.java

Author: sabob
Date: Tue Jul 20 12:47:34 2010
New Revision: 965830

URL: http://svn.apache.org/viewvc?rev=965830&view=rev
Log:
use consistent method names

Modified:
    click/trunk/click/framework/src/org/apache/click/ClickServlet.java

Modified: click/trunk/click/framework/src/org/apache/click/ClickServlet.java
URL: http://svn.apache.org/viewvc/click/trunk/click/framework/src/org/apache/click/ClickServlet.java?rev=965830&r1=965829&r2=965830&view=diff
==============================================================================
--- click/trunk/click/framework/src/org/apache/click/ClickServlet.java (original)
+++ click/trunk/click/framework/src/org/apache/click/ClickServlet.java Tue Jul 20 12:47:34 2010
@@ -1829,7 +1829,7 @@ public class ClickServlet extends HttpSe
             if (controlRegistry.hasAjaxTargetControls() && !context.isForward()) {
 
                 // Perform onProcess for regsitered Ajax controls
-                processAjaxControls(context, eventDispatcher, controlRegistry);
+                processAjaxTargetControls(context, eventDispatcher, controlRegistry);
 
                 // Fire behaviors registered during the onProcess event
                 // The target behavior will set the eventDispatcher partial instance
@@ -1879,7 +1879,7 @@ public class ClickServlet extends HttpSe
     }
 
     /**
      * Process all Ajax controls and return true if the page should continue
      * processing, false otherwise.
      *
      * @param context the request context
@@ -1887,7 +1887,7 @@ public class ClickServlet extends HttpSe
      * @param controlRegistry the control registry
      * @return true if the page should continue processing, false otherwise
      */
-    protected boolean processAjaxControls(Context context,
+    protected boolean processAjaxTargetControls(Context context,
         ActionEventDispatcher eventDispatcher, ControlRegistry controlRegistry) {
 
         boolean continueProcessing = true;
@@ -1879,7 +1879,7 @@ public class ClickServlet extends HttpSe
 
     /**
-     * Process all Ajax controls and return true if the page should continue
+     * Process all Ajax target controls and return true if the page should continue
      * processing, false otherwise.
      *